FileStore

Struct FileStore 

pub struct FileStore {
    pub dir: &'static str,
    pub prefix: &'static str,
    pub extension: &'static str,
}
Creates a FileStore struct and stores its configuration. Specifying the dir, prefix, and extension fields will define how session.

For example, if you were to use:

    FileStore::new("/path/to/sesssions/directory", "prefix-", ".json")

to instantiate a new FileStore struct, then you would end up with files such as:

    /path/to/sesssions/directory/prefix-CI4afkzk6tVMRb50lMyZAA.json
    /path/to/sesssions/directory/prefix-Hs8Jb0_zAGrc_rmUYGwlvw.json
    /path/to/sesssions/directory/prefix-swJdTjvk1os8zAhhc6AVMQ.json

Fields

dir: &'static str

Directory to use for session storage. Omit any trailing slashes or path separators.

prefix: &'static str

Optional prefix for session files. If not empty, all files will begin with this prefix

extension: &'static str

Implementations

Source

impl FileStore

pub fn new( dir: &'static str, prefix: &'static str, extension: &'static str, ) -> Self

Creates a new FileStore struct with the specified dir, prefix, and extensions fields.

pub fn in_dir(d: &'static str) -> Self

Creates a new FileStore struct with the specified dir field and blank prefix and extension fields.

pub fn path(&self, session_id: &Id) -> String

Returns the full path a session with the given session_id should be found or created at.